==> ros-melodic-avt-vimba-camera_0.0.12.orig.tar.gz: ros-melodic-avt-vimba-camera-0.0.12/include/VimbaCPP/Source/Helper.h <==
/*=============================================================================
  Copyright (C) 2012 Allied Vision Technologies.  All Rights Reserved.

  Redistribution of this file, in original or modified form, without
  prior written consent of Allied Vision Technologies is prohibited.

-------------------------------------------------------------------------------

  File:        Helper.h

  Description: Definition of helper classes (types)
               (This include file is for internal use only.)

-------------------------------------------------------------------------------

  THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF TITLE,
  NON-INFRINGEMENT, MERCHANTABILITY AND FITNESS FOR A PARTICULAR  PURPOSE ARE
  DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, 
  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
  (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED  
  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR 
  TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=============================================================================*/

#ifndef AVT_VMBAPI_HELPER_H
#define AVT_VMBAPI_HELPER_H

#include <VimbaCPP/Include/BasicLockable.h>

namespace AVT {
namespace VmbAPI {

template <class T>
class LockableVector : public virtual BasicLockable
{
  public:
    std::vector<T> Vector;
};

template <class T1, class T2>
class LockableMap : public virtual BasicLockable
{
  public:
    std::map<T1, T2> Map;
};

char const * const AVT_IP_OR_MAC_ADDRESS = "IP_OR_MAC@";

}} // AVT::VmbAPI

#endif

==> ros-melodic-avt-vimba-camera_1.2.0.orig.tar.gz: ros-melodic-avt-vimba-camera-1.2.0/include/VimbaCPP/Source/Helper.h <==
/*=============================================================================
  Copyright (C) 2012 Allied Vision Technologies.  All Rights Reserved.

  Redistribution of this file, in original or modified form, without
  prior written consent of Allied Vision Technologies is prohibited.

-------------------------------------------------------------------------------

  File:        Helper.h

  Description: Definition of helper classes (types)
               Intended for use in the implementation of Vimba CPP API.

-------------------------------------------------------------------------------

  THIS SOFTWARE IS PROVIDED BY THE AUTHOR "AS IS" AND ANY EXPRESS OR IMPLIED
  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF TITLE,
  NON-INFRINGEMENT, MERCHANTABILITY AND FITNESS FOR A PARTICULAR  PURPOSE ARE
  DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, 
  INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES 
  (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
  LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED  
  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR 
  TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE 
  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=============================================================================*/

#ifndef AVT_VMBAPI_HELPER_H
#define AVT_VMBAPI_HELPER_H

#include <VimbaCPP/Include/BasicLockable.h>

namespace AVT {
namespace VmbAPI {

template <class T>
class LockableVector : public virtual BasicLockable
{
  public:
    std::vector<T> Vector;
};

template <class T1, class T2>
class LockableMap : public virtual BasicLockable
{
  public:
    std::map<T1, T2> Map;
};

char const * const AVT_IP_OR_MAC_ADDRESS = "IP_OR_MAC@";

}} // AVT::VmbAPI

#endif
